Repeat

Struct Repeat 

pub struct Repeat<O> { /* private fields */ }
Applies an operator n times and collects all results into one population.

Examples

use evolve::operators::sequential::combinator::Repeat;
use evolve::operators::sequential::mutation::RandomReset;

// Run mutation 5 times and merge the results
let op = Repeat::new(RandomReset::<u8>::new(), 5);

Implementations

Source

impl<O> Repeat<O>

pub fn new(operator: O, n: usize) -> Self

Creates a new Repeat that applies the operator n times.